@@ -4,6 +4,7 @@
 #   recommended to explore this file.
 ###############################################################################
 from random import shuffle
+import matplotlib.colors as mcolors
 
 ###############################################################################
 # Splatoon 1
@@ -166,6 +167,7 @@ ROCK_PAPER_SCISSORS_S3      = ('#413BBA', '#BEB013', '#C03E3E', '#35BA49')
 GEAR_GRUB_FUN_S3            = ('#8A19F7', '#BE7118', '#28C05E', '#3F2CD2')
 GRASS_FIRE_WATER_S3         = ('#1BA974', '#DA4514', '#002AFF', '#FFFF00')
 SPICY_SWEET_SOUR_S3         = ('#AD5438', '#9A6FCC', '#A5B533', '#00A2E8')
+DARK_MILK_WHITE_S3          = ('#3D1F7A', '#995935', '#D6BF8F', '#FFFF00')
 # Return of the Mammalians ----------------------------------------------------
 ORANGE_V_BLUE_S3            = ('#EE8711', '#0943F0', '#81DE17')
 YELLOW_V_INDIGO_S3          = ('#DEC109', '#531BBA', '#C920B7')
@@ -202,4 +204,13 @@ for name in all_variables:
         vals = list(eval(name))
         ALL_COLORS.extend(vals)
 ALL_COLORS = list(set(ALL_COLORS))
-shuffle(ALL_COLORS)
\ No newline at end of file
+shuffle(ALL_COLORS)
+
+###############################################################################
+# Auxiliary Functions
+###############################################################################
+def colorPaletteFromHexList(clist):
+    c = mcolors.ColorConverter().to_rgba
+    clrs = [c(i) for i in clist]
+    rvb = mcolors.LinearSegmentedColormap.from_list("", clrs)
+    return rvb
