@@ -892,7 +892,8 @@ def polarBarChart(
         figAx=None,
         logScale=False, ticksStep=10,
         rRange=(0, 270), yRange=None,
-        colors=clr.ALL_COLORS,
+        colors=clr.ALL_COLORS, 
+        edgecolor='#00000000', linewidth=0,
         labels=True, labelQty=False,
         origin='N', direction=1,
         ticksFmt={
@@ -934,8 +935,19 @@ def polarBarChart(
         for j in (yValsSca, gridYSca)
     ]
     # Generate Plot -----------------------------------------------------------
+    bars = []
     for (i, ang) in enumerate(angleHeights):
-        ax.barh(i, radians(ang), color=colors[i])
+        b = ax.barh(
+            i, radians(ang), 
+            color=colors[i], # edgecolor=edgecolor, linewidth=linewidth
+        )
+        bars.append(b)
+    for bar in bars:
+        x, y = bar[0].get_xy()
+        w, h = bar[0].get_width(), bar[0].get_height()
+        # ax.plot([x, x], [y, y + h], color='black', lw=4)
+        # ax.plot([x, x + w], [y + h, y + h], color='black', lw=4)
+        ax.plot([x+w, x+w], [y, y+h], color=edgecolor, lw=linewidth)
     # Gridlines and axes ------------------------------------------------------
     ax.vlines(
         [radians(i) for i in grids[:ticksStep+1]], 
@@ -950,6 +962,7 @@ def polarBarChart(
     ax.set_theta_direction(direction)
     ax.set_rlabel_position(0)
     # Labels ------------------------------------------------------------------
+    fig.canvas.draw()
     labelsText = [ticksFmt['fmt'].format(i) for i in gridY] if labels else []
     ax.set_thetagrids(
         grids[:ticksStep+1], labelsText[:ticksStep+1], 
